@@ -1,4 +1,3 @@
-import logging
 from baseoperation import BaseOperation
 
 
@@ -7,10 +6,6 @@ class ListOperation(BaseOperation):
         super(ListOperation, self).__init__(group_id, args, {'output': output})
 
     def run(self, repo):
-        # suppress logging
-        logging.getLogger().disabled = True
-        repo.load()
-        logging.getLogger().disabled = False
-
-        repo.print_list(self.group_id, self.output)
+        repo.load_all()
+        repo.print_list(self.output)
         return 0
